==> soliq_id-1.2.49.tar.gz: lib/src/utils/faceid_localizations.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class FaceIdLocalization {
  FaceIdLocalization(this.locale);

  final Locale locale;

  static FaceIdLocalization? of(BuildContext context) {
    return Localizations.of<FaceIdLocalization>(context, FaceIdLocalization);
  }

  late Map<String, String> _localizedValues;

  Future<void> load() async {
    var langSourceName = langChoose(locale.countryCode);
    String jsonStringValues =
        await rootBundle.loadString('lib/src/assets/lang/$langSourceName.json');
    Map<String, dynamic> mappedJson = json.decode(jsonStringValues);
    _localizedValues =
        mappedJson.map((key, value) => MapEntry(key, value.toString()));
  }

  String translate(String key) {
    var travel = "";
    _localizedValues.forEach((_key, value) {
      if (_key == key) {
        travel = value;
      }
    });
    return travel;
  }

  // static member to have simple access to the delegate from Material App
  static const LocalizationsDelegate<FaceIdLocalization> delegate =
      _FaceIdLocalizationsDelegate();

  String langChoose(String? countryCode) {
  if (countryCode == "KA") {
      return "ka";
    } else if (countryCode == "US") {
      return "eng";
    }

    return (countryCode ?? 'UZ').toLowerCase();
  }
}

class _FaceIdLocalizationsDelegate
    extends LocalizationsDelegate<FaceIdLocalization> {
  const _FaceIdLocalizationsDelegate();

  @override
  bool isSupported(Locale locale) {
    return ['uz', 'ru', 'en', 'ka','eng',].contains(locale.languageCode);
  }

  @override
  Future<FaceIdLocalization> load(Locale locale) async {
    FaceIdLocalization localization = FaceIdLocalization(locale);
    await localization.load();
    return localization;
  }

  @override
  bool shouldReload(LocalizationsDelegate<FaceIdLocalization> old) => false;
}

Locale locale(String languageCode) {
  switch (languageCode) {
    case 'uz':
      return const  Locale('uz', 'UZ');
    case 'ru':
      return const Locale('ru', "RU");
    case 'eng':
      return const Locale('en', "US");
    case 'ka':
      return const Locale('ka', "KA");
    case 'en':
      return const Locale('en', "EN");

    default:
      return const Locale('uz', 'UZ');
  }
}

String getTranslated(BuildContext context, String key) {
  return FaceIdLocalization.of(context)!.translate(key);
}

==> soliq_id-1.4.37.tar.gz: lib/src/utils/faceid_localizations.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class FaceIdLocalization {
  FaceIdLocalization(this.locale);

  final Locale locale;

  static FaceIdLocalization? of(BuildContext context) {
    return Localizations.of<FaceIdLocalization>(context, FaceIdLocalization);
  }

  late Map<String, String> _localizedValues;

  Future<void> load() async {
    var langSourceName = langChoose(locale.countryCode);
    String jsonStringValues =
        await rootBundle.loadString('assets/lang/$langSourceName.json');
    Map<String, dynamic> mappedJson = json.decode(jsonStringValues);
    _localizedValues =
        mappedJson.map((key, value) => MapEntry(key, value.toString()));
  }

  String translate(String key) {
    var travel = "";
    _localizedValues.forEach((_key, value) {
      if (_key == key) {
        travel = value;
      }
    });
    return travel;
  }

  // static member to have simple access to the delegate from Material App
  static const LocalizationsDelegate<FaceIdLocalization> delegate =
      _FaceIdLocalizationsDelegate();

  String langChoose(String? countryCode) {
  if (countryCode == "KA") {
      return "ka";
    } else if (countryCode == "US") {
      return "eng";
    }

    return (countryCode ?? 'UZ').toLowerCase();
  }
}

class _FaceIdLocalizationsDelegate
    extends LocalizationsDelegate<FaceIdLocalization> {
  const _FaceIdLocalizationsDelegate();

  @override
  bool isSupported(Locale locale) {
    return ['uz', 'ru', 'en', 'ka','eng',].contains(locale.languageCode);
  }

  @override
  Future<FaceIdLocalization> load(Locale locale) async {
    FaceIdLocalization localization = FaceIdLocalization(locale);
    await localization.load();
    return localization;
  }

  @override
  bool shouldReload(LocalizationsDelegate<FaceIdLocalization> old) => false;
}

Locale locale(String languageCode) {
  switch (languageCode) {
    case 'uz':
      return const  Locale('uz', 'UZ');
    case 'ru':
      return const Locale('ru', "RU");
    case 'eng':
      return const Locale('en', "US");
    case 'ka':
      return const Locale('ka', "KA");
    case 'en':
      return const Locale('en', "EN");

    default:
      return const Locale('uz', 'UZ');
  }
}

String getTranslated(BuildContext context, String key) {
  return FaceIdLocalization.of(context)!.translate(key);
}
